@@ -364,6 +364,25 @@ def monitoring_run_time(f):
     return wrapper
 
 
+def judge_time(ti: str, st: str, en: str):
+    """
+    字段格式：0000-00-00 00:00:00
+    判断时间ti是否在be和en之间，返回True或False
+    :param ti: 判断时间
+    :param st: 范围开始时间
+    :param en: 范围结束时间
+    :return: True or  False
+    """
+    d_time_st = datetime.datetime.strptime(ti, '%Y-%m-%d %H:%M:%S')
+    d_time_en = datetime.datetime.strptime(st, '%Y-%m-%d %H:%M:%S')
+    n_time = datetime.datetime.strptime(en, '%Y-%m-%d %H:%M:%S')
+    assert d_time_en > d_time_st, "时间范围需结束时间大于开始时间！"
+    if n_time > d_time_st and n_time < d_time_en:
+        return True
+    else:
+        return False
+
+
 @retry(stop_max_attempt_number=10)
 def get_taobao_time():
     """获取在线时间{"sysTime2":"2021-01-12 16:41:50","sysTime1":"20210112164150"}"""
